from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.text_to_company_search_params_response_200_output_search_params_headquarters_location_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersLocationType0
  from ..models.text_to_company_search_params_response_200_output_search_params_total_funding_usd_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsTotalFundingUSDType0
  from ..models.text_to_company_search_params_response_200_output_search_params_stage_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsStageType0
  from ..models.text_to_company_search_params_response_200_output_search_params_founded_on_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType0
  from ..models.text_to_company_search_params_response_200_output_search_params_tags_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsTagsType0
  from ..models.text_to_company_search_params_response_200_output_search_params_naics_codes_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsNaicsCodesType0
  from ..models.text_to_company_search_params_response_200_output_search_params_exact_company_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsExactCompanyV2Type0
  from ..models.text_to_company_search_params_response_200_output_search_params_last_funded_on_type_1 import TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType1
  from ..models.text_to_company_search_params_response_200_output_search_params_last_funding_usd_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsLastFundingUSDType0
  from ..models.text_to_company_search_params_response_200_output_search_params_job_postings_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsJobPostingsV2Type0
  from ..models.text_to_company_search_params_response_200_output_search_params_revenue_usd_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0
  from ..models.text_to_company_search_params_response_200_output_search_params_technologies_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsTechnologiesType0
  from ..models.text_to_company_search_params_response_200_output_search_params_accelerators_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsAcceleratorsV2Type0
  from ..models.text_to_company_search_params_response_200_output_search_params_headquarters_state_name_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersStateNameType0
  from ..models.text_to_company_search_params_response_200_output_search_params_name_like_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsNameLikeType0
  from ..models.text_to_company_search_params_response_200_output_search_params_founded_on_type_1 import TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType1
  from ..models.text_to_company_search_params_response_200_output_search_params_keywords_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsKeywordsType0
  from ..models.text_to_company_search_params_response_200_output_search_params_industries_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsIndustriesV2Type0
  from ..models.text_to_company_search_params_response_200_output_search_params_headquarters_country_code_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersCountryCodeType0
  from ..models.text_to_company_search_params_response_200_output_search_params_investors_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsInvestorsType0
  from ..models.text_to_company_search_params_response_200_output_search_params_employee_count_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0
  from ..models.text_to_company_search_params_response_200_output_search_params_office_locations_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0
  from ..models.text_to_company_search_params_response_200_output_search_params_last_funded_on_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType0





T = TypeVar("T", bound="TextToCompanySearchParamsResponse200OutputSearchParams")



@_attrs_define
class TextToCompanySearchParamsResponse200OutputSearchParams:
    """ 
        Attributes:
            headquarters_country_code
                (Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersCountryCodeType0', None, Unset]):
            headquarters_state_name
                (Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersStateNameType0', None, Unset]):
            employee_count_v2 (Union['TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0', None,
                Unset]):
            keywords (Union['TextToCompanySearchParamsResponse200OutputSearchParamsKeywordsType0', None, Unset]):
            industries_v2 (Union['TextToCompanySearchParamsResponse200OutputSearchParamsIndustriesV2Type0', None, Unset]):
            stage (Union['TextToCompanySearchParamsResponse200OutputSearchParamsStageType0', None, Unset]):
            total_funding_usd (Union['TextToCompanySearchParamsResponse200OutputSearchParamsTotalFundingUSDType0', None,
                Unset]):
            last_funding_usd (Union['TextToCompanySearchParamsResponse200OutputSearchParamsLastFundingUSDType0', None,
                Unset]):
            last_funded_on (Union['TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType0',
                'TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType1', None, Unset]):
            founded_on (Union['TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType0',
                'TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType1', None, Unset]):
            investors (Union['TextToCompanySearchParamsResponse200OutputSearchParamsInvestorsType0', None, Unset]):
            name_like (Union['TextToCompanySearchParamsResponse200OutputSearchParamsNameLikeType0', None, Unset]):
            accelerators_v2 (Union['TextToCompanySearchParamsResponse200OutputSearchParamsAcceleratorsV2Type0', None,
                Unset]):
            headquarters_location (Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersLocationType0',
                None, Unset]):
            job_postings_v2 (Union['TextToCompanySearchParamsResponse200OutputSearchParamsJobPostingsV2Type0', None,
                Unset]):
            tags (Union['TextToCompanySearchParamsResponse200OutputSearchParamsTagsType0', None, Unset]):
            revenue_usd (Union['TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0', None, Unset]):
            office_locations_v2 (Union['TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0', None,
                Unset]):
            naics_codes (Union['TextToCompanySearchParamsResponse200OutputSearchParamsNaicsCodesType0', None, Unset]):
            technologies (Union['TextToCompanySearchParamsResponse200OutputSearchParamsTechnologiesType0', None, Unset]):
            exact_company_v2 (Union['TextToCompanySearchParamsResponse200OutputSearchParamsExactCompanyV2Type0', None,
                Unset]):
     """

    headquarters_country_code: Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersCountryCodeType0', None, Unset] = UNSET
    headquarters_state_name: Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersStateNameType0', None, Unset] = UNSET
    employee_count_v2: Union['TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0', None, Unset] = UNSET
    keywords: Union['TextToCompanySearchParamsResponse200OutputSearchParamsKeywordsType0', None, Unset] = UNSET
    industries_v2: Union['TextToCompanySearchParamsResponse200OutputSearchParamsIndustriesV2Type0', None, Unset] = UNSET
    stage: Union['TextToCompanySearchParamsResponse200OutputSearchParamsStageType0', None, Unset] = UNSET
    total_funding_usd: Union['TextToCompanySearchParamsResponse200OutputSearchParamsTotalFundingUSDType0', None, Unset] = UNSET
    last_funding_usd: Union['TextToCompanySearchParamsResponse200OutputSearchParamsLastFundingUSDType0', None, Unset] = UNSET
    last_funded_on: Union['TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType0', 'TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType1', None, Unset] = UNSET
    founded_on: Union['TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType0', 'TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType1', None, Unset] = UNSET
    investors: Union['TextToCompanySearchParamsResponse200OutputSearchParamsInvestorsType0', None, Unset] = UNSET
    name_like: Union['TextToCompanySearchParamsResponse200OutputSearchParamsNameLikeType0', None, Unset] = UNSET
    accelerators_v2: Union['TextToCompanySearchParamsResponse200OutputSearchParamsAcceleratorsV2Type0', None, Unset] = UNSET
    headquarters_location: Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersLocationType0', None, Unset] = UNSET
    job_postings_v2: Union['TextToCompanySearchParamsResponse200OutputSearchParamsJobPostingsV2Type0', None, Unset] = UNSET
    tags: Union['TextToCompanySearchParamsResponse200OutputSearchParamsTagsType0', None, Unset] = UNSET
    revenue_usd: Union['TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0', None, Unset] = UNSET
    office_locations_v2: Union['TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0', None, Unset] = UNSET
    naics_codes: Union['TextToCompanySearchParamsResponse200OutputSearchParamsNaicsCodesType0', None, Unset] = UNSET
    technologies: Union['TextToCompanySearchParamsResponse200OutputSearchParamsTechnologiesType0', None, Unset] = UNSET
    exact_company_v2: Union['TextToCompanySearchParamsResponse200OutputSearchParamsExactCompanyV2Type0', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.text_to_company_search_params_response_200_output_search_params_headquarters_location_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersLocationType0
        from ..models.text_to_company_search_params_response_200_output_search_params_total_funding_usd_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsTotalFundingUSDType0
        from ..models.text_to_company_search_params_response_200_output_search_params_stage_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsStageType0
        from ..models.text_to_company_search_params_response_200_output_search_params_founded_on_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType0
        from ..models.text_to_company_search_params_response_200_output_search_params_tags_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsTagsType0
        from ..models.text_to_company_search_params_response_200_output_search_params_naics_codes_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsNaicsCodesType0
        from ..models.text_to_company_search_params_response_200_output_search_params_exact_company_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsExactCompanyV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_last_funded_on_type_1 import TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType1
        from ..models.text_to_company_search_params_response_200_output_search_params_last_funding_usd_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsLastFundingUSDType0
        from ..models.text_to_company_search_params_response_200_output_search_params_job_postings_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsJobPostingsV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_revenue_usd_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0
        from ..models.text_to_company_search_params_response_200_output_search_params_technologies_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsTechnologiesType0
        from ..models.text_to_company_search_params_response_200_output_search_params_accelerators_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsAcceleratorsV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_headquarters_state_name_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersStateNameType0
        from ..models.text_to_company_search_params_response_200_output_search_params_name_like_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsNameLikeType0
        from ..models.text_to_company_search_params_response_200_output_search_params_founded_on_type_1 import TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType1
        from ..models.text_to_company_search_params_response_200_output_search_params_keywords_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsKeywordsType0
        from ..models.text_to_company_search_params_response_200_output_search_params_industries_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsIndustriesV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_headquarters_country_code_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersCountryCodeType0
        from ..models.text_to_company_search_params_response_200_output_search_params_investors_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsInvestorsType0
        from ..models.text_to_company_search_params_response_200_output_search_params_employee_count_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_office_locations_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_last_funded_on_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType0
        headquarters_country_code: Union[None, Unset, dict[str, Any]]
        if isinstance(self.headquarters_country_code, Unset):
            headquarters_country_code = UNSET
        elif isinstance(self.headquarters_country_code, TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersCountryCodeType0):
            headquarters_country_code = self.headquarters_country_code.to_dict()
        else:
            headquarters_country_code = self.headquarters_country_code

        headquarters_state_name: Union[None, Unset, dict[str, Any]]
        if isinstance(self.headquarters_state_name, Unset):
            headquarters_state_name = UNSET
        elif isinstance(self.headquarters_state_name, TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersStateNameType0):
            headquarters_state_name = self.headquarters_state_name.to_dict()
        else:
            headquarters_state_name = self.headquarters_state_name

        employee_count_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.employee_count_v2, Unset):
            employee_count_v2 = UNSET
        elif isinstance(self.employee_count_v2, TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0):
            employee_count_v2 = self.employee_count_v2.to_dict()
        else:
            employee_count_v2 = self.employee_count_v2

        keywords: Union[None, Unset, dict[str, Any]]
        if isinstance(self.keywords, Unset):
            keywords = UNSET
        elif isinstance(self.keywords, TextToCompanySearchParamsResponse200OutputSearchParamsKeywordsType0):
            keywords = self.keywords.to_dict()
        else:
            keywords = self.keywords

        industries_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.industries_v2, Unset):
            industries_v2 = UNSET
        elif isinstance(self.industries_v2, TextToCompanySearchParamsResponse200OutputSearchParamsIndustriesV2Type0):
            industries_v2 = self.industries_v2.to_dict()
        else:
            industries_v2 = self.industries_v2

        stage: Union[None, Unset, dict[str, Any]]
        if isinstance(self.stage, Unset):
            stage = UNSET
        elif isinstance(self.stage, TextToCompanySearchParamsResponse200OutputSearchParamsStageType0):
            stage = self.stage.to_dict()
        else:
            stage = self.stage

        total_funding_usd: Union[None, Unset, dict[str, Any]]
        if isinstance(self.total_funding_usd, Unset):
            total_funding_usd = UNSET
        elif isinstance(self.total_funding_usd, TextToCompanySearchParamsResponse200OutputSearchParamsTotalFundingUSDType0):
            total_funding_usd = self.total_funding_usd.to_dict()
        else:
            total_funding_usd = self.total_funding_usd

        last_funding_usd: Union[None, Unset, dict[str, Any]]
        if isinstance(self.last_funding_usd, Unset):
            last_funding_usd = UNSET
        elif isinstance(self.last_funding_usd, TextToCompanySearchParamsResponse200OutputSearchParamsLastFundingUSDType0):
            last_funding_usd = self.last_funding_usd.to_dict()
        else:
            last_funding_usd = self.last_funding_usd

        last_funded_on: Union[None, Unset, dict[str, Any]]
        if isinstance(self.last_funded_on, Unset):
            last_funded_on = UNSET
        elif isinstance(self.last_funded_on, TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType0):
            last_funded_on = self.last_funded_on.to_dict()
        elif isinstance(self.last_funded_on, TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType1):
            last_funded_on = self.last_funded_on.to_dict()
        else:
            last_funded_on = self.last_funded_on

        founded_on: Union[None, Unset, dict[str, Any]]
        if isinstance(self.founded_on, Unset):
            founded_on = UNSET
        elif isinstance(self.founded_on, TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType0):
            founded_on = self.founded_on.to_dict()
        elif isinstance(self.founded_on, TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType1):
            founded_on = self.founded_on.to_dict()
        else:
            founded_on = self.founded_on

        investors: Union[None, Unset, dict[str, Any]]
        if isinstance(self.investors, Unset):
            investors = UNSET
        elif isinstance(self.investors, TextToCompanySearchParamsResponse200OutputSearchParamsInvestorsType0):
            investors = self.investors.to_dict()
        else:
            investors = self.investors

        name_like: Union[None, Unset, dict[str, Any]]
        if isinstance(self.name_like, Unset):
            name_like = UNSET
        elif isinstance(self.name_like, TextToCompanySearchParamsResponse200OutputSearchParamsNameLikeType0):
            name_like = self.name_like.to_dict()
        else:
            name_like = self.name_like

        accelerators_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.accelerators_v2, Unset):
            accelerators_v2 = UNSET
        elif isinstance(self.accelerators_v2, TextToCompanySearchParamsResponse200OutputSearchParamsAcceleratorsV2Type0):
            accelerators_v2 = self.accelerators_v2.to_dict()
        else:
            accelerators_v2 = self.accelerators_v2

        headquarters_location: Union[None, Unset, dict[str, Any]]
        if isinstance(self.headquarters_location, Unset):
            headquarters_location = UNSET
        elif isinstance(self.headquarters_location, TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersLocationType0):
            headquarters_location = self.headquarters_location.to_dict()
        else:
            headquarters_location = self.headquarters_location

        job_postings_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.job_postings_v2, Unset):
            job_postings_v2 = UNSET
        elif isinstance(self.job_postings_v2, TextToCompanySearchParamsResponse200OutputSearchParamsJobPostingsV2Type0):
            job_postings_v2 = self.job_postings_v2.to_dict()
        else:
            job_postings_v2 = self.job_postings_v2

        tags: Union[None, Unset, dict[str, Any]]
        if isinstance(self.tags, Unset):
            tags = UNSET
        elif isinstance(self.tags, TextToCompanySearchParamsResponse200OutputSearchParamsTagsType0):
            tags = self.tags.to_dict()
        else:
            tags = self.tags

        revenue_usd: Union[None, Unset, dict[str, Any]]
        if isinstance(self.revenue_usd, Unset):
            revenue_usd = UNSET
        elif isinstance(self.revenue_usd, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0):
            revenue_usd = self.revenue_usd.to_dict()
        else:
            revenue_usd = self.revenue_usd

        office_locations_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.office_locations_v2, Unset):
            office_locations_v2 = UNSET
        elif isinstance(self.office_locations_v2, TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0):
            office_locations_v2 = self.office_locations_v2.to_dict()
        else:
            office_locations_v2 = self.office_locations_v2

        naics_codes: Union[None, Unset, dict[str, Any]]
        if isinstance(self.naics_codes, Unset):
            naics_codes = UNSET
        elif isinstance(self.naics_codes, TextToCompanySearchParamsResponse200OutputSearchParamsNaicsCodesType0):
            naics_codes = self.naics_codes.to_dict()
        else:
            naics_codes = self.naics_codes

        technologies: Union[None, Unset, dict[str, Any]]
        if isinstance(self.technologies, Unset):
            technologies = UNSET
        elif isinstance(self.technologies, TextToCompanySearchParamsResponse200OutputSearchParamsTechnologiesType0):
            technologies = self.technologies.to_dict()
        else:
            technologies = self.technologies

        exact_company_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.exact_company_v2, Unset):
            exact_company_v2 = UNSET
        elif isinstance(self.exact_company_v2, TextToCompanySearchParamsResponse200OutputSearchParamsExactCompanyV2Type0):
            exact_company_v2 = self.exact_company_v2.to_dict()
        else:
            exact_company_v2 = self.exact_company_v2


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if headquarters_country_code is not UNSET:
            field_dict["headquartersCountryCode"] = headquarters_country_code
        if headquarters_state_name is not UNSET:
            field_dict["headquartersStateName"] = headquarters_state_name
        if employee_count_v2 is not UNSET:
            field_dict["employeeCountV2"] = employee_count_v2
        if keywords is not UNSET:
            field_dict["keywords"] = keywords
        if industries_v2 is not UNSET:
            field_dict["industriesV2"] = industries_v2
        if stage is not UNSET:
            field_dict["stage"] = stage
        if total_funding_usd is not UNSET:
            field_dict["totalFundingUSD"] = total_funding_usd
        if last_funding_usd is not UNSET:
            field_dict["lastFundingUSD"] = last_funding_usd
        if last_funded_on is not UNSET:
            field_dict["lastFundedOn"] = last_funded_on
        if founded_on is not UNSET:
            field_dict["foundedOn"] = founded_on
        if investors is not UNSET:
            field_dict["investors"] = investors
        if name_like is not UNSET:
            field_dict["nameLike"] = name_like
        if accelerators_v2 is not UNSET:
            field_dict["acceleratorsV2"] = accelerators_v2
        if headquarters_location is not UNSET:
            field_dict["headquartersLocation"] = headquarters_location
        if job_postings_v2 is not UNSET:
            field_dict["jobPostingsV2"] = job_postings_v2
        if tags is not UNSET:
            field_dict["tags"] = tags
        if revenue_usd is not UNSET:
            field_dict["revenueUSD"] = revenue_usd
        if office_locations_v2 is not UNSET:
            field_dict["officeLocationsV2"] = office_locations_v2
        if naics_codes is not UNSET:
            field_dict["naicsCodes"] = naics_codes
        if technologies is not UNSET:
            field_dict["technologies"] = technologies
        if exact_company_v2 is not UNSET:
            field_dict["exactCompanyV2"] = exact_company_v2

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.text_to_company_search_params_response_200_output_search_params_headquarters_location_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersLocationType0
        from ..models.text_to_company_search_params_response_200_output_search_params_total_funding_usd_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsTotalFundingUSDType0
        from ..models.text_to_company_search_params_response_200_output_search_params_stage_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsStageType0
        from ..models.text_to_company_search_params_response_200_output_search_params_founded_on_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType0
        from ..models.text_to_company_search_params_response_200_output_search_params_tags_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsTagsType0
        from ..models.text_to_company_search_params_response_200_output_search_params_naics_codes_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsNaicsCodesType0
        from ..models.text_to_company_search_params_response_200_output_search_params_exact_company_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsExactCompanyV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_last_funded_on_type_1 import TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType1
        from ..models.text_to_company_search_params_response_200_output_search_params_last_funding_usd_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsLastFundingUSDType0
        from ..models.text_to_company_search_params_response_200_output_search_params_job_postings_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsJobPostingsV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_revenue_usd_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0
        from ..models.text_to_company_search_params_response_200_output_search_params_technologies_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsTechnologiesType0
        from ..models.text_to_company_search_params_response_200_output_search_params_accelerators_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsAcceleratorsV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_headquarters_state_name_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersStateNameType0
        from ..models.text_to_company_search_params_response_200_output_search_params_name_like_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsNameLikeType0
        from ..models.text_to_company_search_params_response_200_output_search_params_founded_on_type_1 import TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType1
        from ..models.text_to_company_search_params_response_200_output_search_params_keywords_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsKeywordsType0
        from ..models.text_to_company_search_params_response_200_output_search_params_industries_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsIndustriesV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_headquarters_country_code_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersCountryCodeType0
        from ..models.text_to_company_search_params_response_200_output_search_params_investors_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsInvestorsType0
        from ..models.text_to_company_search_params_response_200_output_search_params_employee_count_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_office_locations_v2_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0
        from ..models.text_to_company_search_params_response_200_output_search_params_last_funded_on_type_0 import TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType0
        d = dict(src_dict)
        def _parse_headquarters_country_code(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersCountryCodeType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                headquarters_country_code_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersCountryCodeType0.from_dict(data)



                return headquarters_country_code_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersCountryCodeType0', None, Unset], data)

        headquarters_country_code = _parse_headquarters_country_code(d.pop("headquartersCountryCode", UNSET))


        def _parse_headquarters_state_name(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersStateNameType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                headquarters_state_name_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersStateNameType0.from_dict(data)



                return headquarters_state_name_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersStateNameType0', None, Unset], data)

        headquarters_state_name = _parse_headquarters_state_name(d.pop("headquartersStateName", UNSET))


        def _parse_employee_count_v2(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                employee_count_v2_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0.from_dict(data)



                return employee_count_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0', None, Unset], data)

        employee_count_v2 = _parse_employee_count_v2(d.pop("employeeCountV2", UNSET))


        def _parse_keywords(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsKeywordsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                keywords_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsKeywordsType0.from_dict(data)



                return keywords_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsKeywordsType0', None, Unset], data)

        keywords = _parse_keywords(d.pop("keywords", UNSET))


        def _parse_industries_v2(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsIndustriesV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                industries_v2_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsIndustriesV2Type0.from_dict(data)



                return industries_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsIndustriesV2Type0', None, Unset], data)

        industries_v2 = _parse_industries_v2(d.pop("industriesV2", UNSET))


        def _parse_stage(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsStageType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                stage_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsStageType0.from_dict(data)



                return stage_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsStageType0', None, Unset], data)

        stage = _parse_stage(d.pop("stage", UNSET))


        def _parse_total_funding_usd(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsTotalFundingUSDType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                total_funding_usd_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsTotalFundingUSDType0.from_dict(data)



                return total_funding_usd_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsTotalFundingUSDType0', None, Unset], data)

        total_funding_usd = _parse_total_funding_usd(d.pop("totalFundingUSD", UNSET))


        def _parse_last_funding_usd(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsLastFundingUSDType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                last_funding_usd_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsLastFundingUSDType0.from_dict(data)



                return last_funding_usd_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsLastFundingUSDType0', None, Unset], data)

        last_funding_usd = _parse_last_funding_usd(d.pop("lastFundingUSD", UNSET))


        def _parse_last_funded_on(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType0', 'TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                last_funded_on_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType0.from_dict(data)



                return last_funded_on_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                last_funded_on_type_1 = TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType1.from_dict(data)



                return last_funded_on_type_1
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType0', 'TextToCompanySearchParamsResponse200OutputSearchParamsLastFundedOnType1', None, Unset], data)

        last_funded_on = _parse_last_funded_on(d.pop("lastFundedOn", UNSET))


        def _parse_founded_on(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType0', 'TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                founded_on_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType0.from_dict(data)



                return founded_on_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                founded_on_type_1 = TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType1.from_dict(data)



                return founded_on_type_1
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType0', 'TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType1', None, Unset], data)

        founded_on = _parse_founded_on(d.pop("foundedOn", UNSET))


        def _parse_investors(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsInvestorsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                investors_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsInvestorsType0.from_dict(data)



                return investors_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsInvestorsType0', None, Unset], data)

        investors = _parse_investors(d.pop("investors", UNSET))


        def _parse_name_like(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsNameLikeType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                name_like_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsNameLikeType0.from_dict(data)



                return name_like_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsNameLikeType0', None, Unset], data)

        name_like = _parse_name_like(d.pop("nameLike", UNSET))


        def _parse_accelerators_v2(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsAcceleratorsV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                accelerators_v2_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsAcceleratorsV2Type0.from_dict(data)



                return accelerators_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsAcceleratorsV2Type0', None, Unset], data)

        accelerators_v2 = _parse_accelerators_v2(d.pop("acceleratorsV2", UNSET))


        def _parse_headquarters_location(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersLocationType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                headquarters_location_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersLocationType0.from_dict(data)



                return headquarters_location_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsHeadquartersLocationType0', None, Unset], data)

        headquarters_location = _parse_headquarters_location(d.pop("headquartersLocation", UNSET))


        def _parse_job_postings_v2(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsJobPostingsV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                job_postings_v2_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsJobPostingsV2Type0.from_dict(data)



                return job_postings_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsJobPostingsV2Type0', None, Unset], data)

        job_postings_v2 = _parse_job_postings_v2(d.pop("jobPostingsV2", UNSET))


        def _parse_tags(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsTagsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                tags_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsTagsType0.from_dict(data)



                return tags_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsTagsType0', None, Unset], data)

        tags = _parse_tags(d.pop("tags", UNSET))


        def _parse_revenue_usd(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                revenue_usd_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0.from_dict(data)



                return revenue_usd_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0', None, Unset], data)

        revenue_usd = _parse_revenue_usd(d.pop("revenueUSD", UNSET))


        def _parse_office_locations_v2(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                office_locations_v2_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0.from_dict(data)



                return office_locations_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0', None, Unset], data)

        office_locations_v2 = _parse_office_locations_v2(d.pop("officeLocationsV2", UNSET))


        def _parse_naics_codes(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsNaicsCodesType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                naics_codes_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsNaicsCodesType0.from_dict(data)



                return naics_codes_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsNaicsCodesType0', None, Unset], data)

        naics_codes = _parse_naics_codes(d.pop("naicsCodes", UNSET))


        def _parse_technologies(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsTechnologiesType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                technologies_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsTechnologiesType0.from_dict(data)



                return technologies_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsTechnologiesType0', None, Unset], data)

        technologies = _parse_technologies(d.pop("technologies", UNSET))


        def _parse_exact_company_v2(data: object) -> Union['TextToCompanySearchParamsResponse200OutputSearchParamsExactCompanyV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                exact_company_v2_type_0 = TextToCompanySearchParamsResponse200OutputSearchParamsExactCompanyV2Type0.from_dict(data)



                return exact_company_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCompanySearchParamsResponse200OutputSearchParamsExactCompanyV2Type0', None, Unset], data)

        exact_company_v2 = _parse_exact_company_v2(d.pop("exactCompanyV2", UNSET))


        text_to_company_search_params_response_200_output_search_params = cls(
            headquarters_country_code=headquarters_country_code,
            headquarters_state_name=headquarters_state_name,
            employee_count_v2=employee_count_v2,
            keywords=keywords,
            industries_v2=industries_v2,
            stage=stage,
            total_funding_usd=total_funding_usd,
            last_funding_usd=last_funding_usd,
            last_funded_on=last_funded_on,
            founded_on=founded_on,
            investors=investors,
            name_like=name_like,
            accelerators_v2=accelerators_v2,
            headquarters_location=headquarters_location,
            job_postings_v2=job_postings_v2,
            tags=tags,
            revenue_usd=revenue_usd,
            office_locations_v2=office_locations_v2,
            naics_codes=naics_codes,
            technologies=technologies,
            exact_company_v2=exact_company_v2,
        )


        text_to_company_search_params_response_200_output_search_params.additional_properties = d
        return text_to_company_search_params_response_200_output_search_params

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class SyncCombinedSearchResponse200OutputCompaniesItemFortuneRankingsType0ItemList(str, Enum):
    FORTUNE_500_USA = "fortune-500-usa"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="CreateCompanyExclusionListFromAudienceBody")



@_attrs_define
class CreateCompanyExclusionListFromAudienceBody:
    """ 
        Attributes:
            api_key (str): Your Fiber API key
            audience_id (str): Id of the audience to create exclusion list from
            name (Union[None, Unset, str]): Name of the company exclusion list. If not provided, defaults to 'Exclusion list
                from {audienceName}'
            is_organization_wide (Union[Unset, bool]): Is the company exclusion list organization wide Default: False.
     """

    api_key: str
    audience_id: str
    name: Union[None, Unset, str] = UNSET
    is_organization_wide: Union[Unset, bool] = False
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        api_key = self.api_key

        audience_id = self.audience_id

        name: Union[None, Unset, str]
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        is_organization_wide = self.is_organization_wide


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "apiKey": api_key,
            "audienceId": audience_id,
        })
        if name is not UNSET:
            field_dict["name"] = name
        if is_organization_wide is not UNSET:
            field_dict["isOrganizationWide"] = is_organization_wide

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        api_key = d.pop("apiKey")

        audience_id = d.pop("audienceId")

        def _parse_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name = _parse_name(d.pop("name", UNSET))


        is_organization_wide = d.pop("isOrganizationWide", UNSET)

        create_company_exclusion_list_from_audience_body = cls(
            api_key=api_key,
            audience_id=audience_id,
            name=name,
            is_organization_wide=is_organization_wide,
        )


        create_company_exclusion_list_from_audience_body.additional_properties = d
        return create_company_exclusion_list_from_audience_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0_rule import CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Rule
from typing import cast

if TYPE_CHECKING:
  from ..models.company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0_count import CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count





T = TypeVar("T", bound="CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0")



@_attrs_define
class CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0:
    """ 
        Attributes:
            rule (CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Rule):
            count (CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count):
     """

    rule: CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Rule
    count: 'CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count'
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0_count import CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count
        rule = self.rule.value

        count = self.count.to_dict()


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "rule": rule,
            "count": count,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0_count import CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count
        d = dict(src_dict)
        rule = CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Rule(d.pop("rule"))




        count = CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count.from_dict(d.pop("count"))




        company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0 = cls(
            rule=rule,
            count=count,
        )


        company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0.additional_properties = d
        return company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.text_to_company_search_params_response_200_output_search_params_office_locations_v2_type_0_none_of_type_0_item_type_1_country_or_region_code import TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1CountryOrRegionCode
from ..models.text_to_company_search_params_response_200_output_search_params_office_locations_v2_type_0_none_of_type_0_item_type_1_type import TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1Type
from typing import cast

if TYPE_CHECKING:
  from ..models.text_to_company_search_params_response_200_output_search_params_office_locations_v2_type_0_none_of_type_0_item_type_1_range import TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1Range





T = TypeVar("T", bound="TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1")



@_attrs_define
class TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1:
    """ 
        Attributes:
            type_ (TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1Type):
            range_ (TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1Range):
            country_or_region_code (TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0I
                temType1CountryOrRegionCode):
     """

    type_: TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1Type
    range_: 'TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1Range'
    country_or_region_code: TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1CountryOrRegionCode
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.text_to_company_search_params_response_200_output_search_params_office_locations_v2_type_0_none_of_type_0_item_type_1_range import TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1Range
        type_ = self.type_.value

        range_ = self.range_.to_dict()

        country_or_region_code = self.country_or_region_code.value


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "range": range_,
            "countryOrRegionCode": country_or_region_code,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.text_to_company_search_params_response_200_output_search_params_office_locations_v2_type_0_none_of_type_0_item_type_1_range import TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1Range
        d = dict(src_dict)
        type_ = TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1Type(d.pop("type"))




        range_ = TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1Range.from_dict(d.pop("range"))




        country_or_region_code = TextToCompanySearchParamsResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType1CountryOrRegionCode(d.pop("countryOrRegionCode"))




        text_to_company_search_params_response_200_output_search_params_office_locations_v2_type_0_none_of_type_0_item_type_1 = cls(
            type_=type_,
            range_=range_,
            country_or_region_code=country_or_region_code,
        )


        text_to_company_search_params_response_200_output_search_params_office_locations_v2_type_0_none_of_type_0_item_type_1.additional_properties = d
        return text_to_company_search_params_response_200_output_search_params_office_locations_v2_type_0_none_of_type_0_item_type_1

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="SyncCombinedSearchResponse200OutputCompaniesItemAcquisitionsType0Item")



@_attrs_define
class SyncCombinedSearchResponse200OutputCompaniesItemAcquisitionsType0Item:
    """ 
        Attributes:
            price_usd (Union[None, Unset, float]):
            acquiree_name (Union[None, Unset, str]):
            acquisition_date (Union[None, Unset, str]):
     """

    price_usd: Union[None, Unset, float] = UNSET
    acquiree_name: Union[None, Unset, str] = UNSET
    acquisition_date: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        price_usd: Union[None, Unset, float]
        if isinstance(self.price_usd, Unset):
            price_usd = UNSET
        else:
            price_usd = self.price_usd

        acquiree_name: Union[None, Unset, str]
        if isinstance(self.acquiree_name, Unset):
            acquiree_name = UNSET
        else:
            acquiree_name = self.acquiree_name

        acquisition_date: Union[None, Unset, str]
        if isinstance(self.acquisition_date, Unset):
            acquisition_date = UNSET
        else:
            acquisition_date = self.acquisition_date


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if price_usd is not UNSET:
            field_dict["price_usd"] = price_usd
        if acquiree_name is not UNSET:
            field_dict["acquiree_name"] = acquiree_name
        if acquisition_date is not UNSET:
            field_dict["acquisition_date"] = acquisition_date

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_price_usd(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        price_usd = _parse_price_usd(d.pop("price_usd", UNSET))


        def _parse_acquiree_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        acquiree_name = _parse_acquiree_name(d.pop("acquiree_name", UNSET))


        def _parse_acquisition_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        acquisition_date = _parse_acquisition_date(d.pop("acquisition_date", UNSET))


        sync_combined_search_response_200_output_companies_item_acquisitions_type_0_item = cls(
            price_usd=price_usd,
            acquiree_name=acquiree_name,
            acquisition_date=acquisition_date,
        )


        sync_combined_search_response_200_output_companies_item_acquisitions_type_0_item.additional_properties = d
        return sync_combined_search_response_200_output_companies_item_acquisitions_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.google_maps_search_body_strategy_type_1_union_all_item_type_0_region_type import GoogleMapsSearchBodyStrategyType1UnionAllItemType0RegionType
from ..types import UNSET, Unset
from typing import cast
from typing import Union

if TYPE_CHECKING:
  from ..models.google_maps_search_body_strategy_type_1_union_all_item_type_0_center import GoogleMapsSearchBodyStrategyType1UnionAllItemType0Center





T = TypeVar("T", bound="GoogleMapsSearchBodyStrategyType1UnionAllItemType0")



@_attrs_define
class GoogleMapsSearchBodyStrategyType1UnionAllItemType0:
    """ 
        Attributes:
            region_type (GoogleMapsSearchBodyStrategyType1UnionAllItemType0RegionType): Use 'circle' to search for places in
                a circle
            center (GoogleMapsSearchBodyStrategyType1UnionAllItemType0Center):
            radius_miles (Union[Unset, float]): The radius of the circle in miles Default: 25.0.
     """

    region_type: GoogleMapsSearchBodyStrategyType1UnionAllItemType0RegionType
    center: 'GoogleMapsSearchBodyStrategyType1UnionAllItemType0Center'
    radius_miles: Union[Unset, float] = 25.0
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.google_maps_search_body_strategy_type_1_union_all_item_type_0_center import GoogleMapsSearchBodyStrategyType1UnionAllItemType0Center
        region_type = self.region_type.value

        center = self.center.to_dict()

        radius_miles = self.radius_miles


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "regionType": region_type,
            "center": center,
        })
        if radius_miles is not UNSET:
            field_dict["radiusMiles"] = radius_miles

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.google_maps_search_body_strategy_type_1_union_all_item_type_0_center import GoogleMapsSearchBodyStrategyType1UnionAllItemType0Center
        d = dict(src_dict)
        region_type = GoogleMapsSearchBodyStrategyType1UnionAllItemType0RegionType(d.pop("regionType"))




        center = GoogleMapsSearchBodyStrategyType1UnionAllItemType0Center.from_dict(d.pop("center"))




        radius_miles = d.pop("radiusMiles", UNSET)

        google_maps_search_body_strategy_type_1_union_all_item_type_0 = cls(
            region_type=region_type,
            center=center,
            radius_miles=radius_miles,
        )


        google_maps_search_body_strategy_type_1_union_all_item_type_0.additional_properties = d
        return google_maps_search_body_strategy_type_1_union_all_item_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CombinedSearchBodyProfileParamsLanguagesType0AllOfType0Item(str, Enum):
    AFRIKAANS = "Afrikaans"
    AKAN = "Akan"
    ALBANIAN = "Albanian"
    ALSATIAN = "Alsatian"
    AMHARIC = "Amharic"
    ARABIC = "Arabic"
    ARMENIAN = "Armenian"
    ASSAMESE = "Assamese"
    ASSYRIAN = "Assyrian"
    AWADHI = "Awadhi"
    AZERBAIJANI = "Azerbaijani"
    BALINESE = "Balinese"
    BALOCHI = "Balochi"
    BAMBARA = "Bambara"
    BASQUE = "Basque"
    BELARUSIAN = "Belarusian"
    BEMBA = "Bemba"
    BENGALI = "Bengali"
    BHOJPURI = "Bhojpuri"
    BISAYA = "Bisaya"
    BOSNIAN = "Bosnian"
    BRETON = "Breton"
    BULGARIAN = "Bulgarian"
    BURMESE = "Burmese"
    CANTONESE = "Cantonese"
    CATALAN = "Catalan"
    CEBUANO = "Cebuano"
    CROATIAN = "Croatian"
    CZECH = "Czech"
    DANISH = "Danish"
    DARI = "Dari"
    DHIVEHI = "Dhivehi"
    DHOLUO = "Dholuo"
    DOGRI = "Dogri"
    DUTCH = "Dutch"
    DZONGKHA = "Dzongkha"
    EFIK = "Efik"
    ENGLISH = "English"
    ESPERANTO = "Esperanto"
    ESTONIAN = "Estonian"
    EWE = "Ewe"
    FANTE = "Fante"
    FAROESE = "Faroese"
    FIJIAN = "Fijian"
    FINNISH = "Finnish"
    FLEMISH = "Flemish"
    FON = "Fon"
    FRENCH = "French"
    FRISIAN = "Frisian"
    FULA = "Fula"
    GA = "Ga"
    GALICIAN = "Galician"
    GARHWALI = "Garhwali"
    GEORGIAN = "Georgian"
    GERMAN = "German"
    GREEK = "Greek"
    GUARANI = "Guarani"
    GUJARATI = "Gujarati"
    HAITIAN_CREOLE = "Haitian Creole"
    HAKKA = "Hakka"
    HARYANVI = "Haryanvi"
    HAUSA = "Hausa"
    HAWAIIAN = "Hawaiian"
    HEBREW = "Hebrew"
    HILIGAYNON = "Hiligaynon"
    HINDI = "Hindi"
    HINDKO = "Hindko"
    HMONG = "Hmong"
    HUNGARIAN = "Hungarian"
    IBAN = "Iban"
    IBIBIO = "Ibibio"
    ICELANDIC = "Icelandic"
    IGALA = "Igala"
    IGBO = "Igbo"
    ILOCANO = "Ilocano"
    INDONESIAN = "Indonesian"
    IRISH = "Irish"
    ITALIAN = "Italian"
    JAPANESE = "Japanese"
    JAVANESE = "Javanese"
    KABYLE = "Kabyle"
    KAMBA = "Kamba"
    KANNADA = "Kannada"
    KAPAMPANGAN = "Kapampangan"
    KASHMIRI = "Kashmiri"
    KAZAKH = "Kazakh"
    KHMER = "Khmer"
    KIKUYU = "Kikuyu"
    KINYARWANDA = "Kinyarwanda"
    KIRUNDI = "Kirundi"
    KONGO = "Kongo"
    KONKANI = "Konkani"
    KOREAN = "Korean"
    KRIO = "Krio"
    KURDISH = "Kurdish"
    KUTCHI = "Kutchi"
    KYRGYZ = "Kyrgyz"
    LAO = "Lao"
    LATIN = "Latin"
    LATVIAN = "Latvian"
    LIMBURGISH = "Limburgish"
    LINGALA = "Lingala"
    LITHUANIAN = "Lithuanian"
    LOZI = "Lozi"
    LUGANDA = "Luganda"
    LUHYA = "Luhya"
    LUXEMBOURGISH = "Luxembourgish"
    MACEDONIAN = "Macedonian"
    MAGAHI = "Magahi"
    MAITHILI = "Maithili"
    MALAGASY = "Malagasy"
    MALAY = "Malay"
    MALAYALAM = "Malayalam"
    MALTESE = "Maltese"
    MANDARIN = "Mandarin"
    MANDINKA = "Mandinka"
    MANIPURI = "Manipuri"
    MAORI = "Maori"
    MARATHI = "Marathi"
    MARWARI = "Marwari"
    MAURITIAN_CREOLE = "Mauritian Creole"
    MINANGKABAU = "Minangkabau"
    MONGOLIAN = "Mongolian"
    MONTENEGRIN = "Montenegrin"
    NAVAJO = "Navajo"
    NEPALI = "Nepali"
    NEWAR = "Newar"
    NORTHERN_NDEBELE = "Northern Ndebele"
    NORTHERN_SOTHO = "Northern Sotho"
    NORTH_FRISIAN = "North Frisian"
    NORWEGIAN = "Norwegian"
    NYANJA = "Nyanja"
    ODIA = "Odia"
    OROMO = "Oromo"
    OVAMBO = "Ovambo"
    PAPIAMENTO = "Papiamento"
    PASHTO = "Pashto"
    PERSIAN = "Persian"
    POLISH = "Polish"
    PORTUGUESE = "Portuguese"
    PUNJABI = "Punjabi"
    PUTONGHUA = "Putonghua"
    QUECHUA = "Quechua"
    RAJASTHANI = "Rajasthani"
    ROMANIAN = "Romanian"
    RUSSIAN = "Russian"
    SAMOAN = "Samoan"
    SANSKRIT = "Sanskrit"
    SARAIKI = "Saraiki"
    SAURASHTRA = "Saurashtra"
    SCOTTISH_GAELIC = "Scottish Gaelic"
    SERBIAN = "Serbian"
    SHANGHAINESE = "Shanghainese"
    SHONA = "Shona"
    SIGN_LANGUAGES = "Sign Languages"
    SINDHI = "Sindhi"
    SINHALESE = "Sinhalese"
    SLOVAK = "Slovak"
    SLOVENIAN = "Slovenian"
    SOGA = "Soga"
    SOMALI = "Somali"
    SOUTHERN_MIN = "Southern Min"
    SOUTHERN_NDEBELE = "Southern Ndebele"
    SOUTHERN_SOTHO = "Southern Sotho"
    SPANISH = "Spanish"
    SRANAN_TONGO = "Sranan Tongo"
    SUNDANESE = "Sundanese"
    SWAHILI = "Swahili"
    SWAZI = "Swazi"
    SWEDISH = "Swedish"
    TAGALOGFILIPINO = "Tagalog/Filipino"
    TAIWANESE_HOKKIEN = "Taiwanese Hokkien"
    TAJIK = "Tajik"
    TAMAZIGHT = "Tamazight"
    TAMIL = "Tamil"
    TATAR = "Tatar"
    TELUGU = "Telugu"
    TEOCHEW = "Teochew"
    TETUM = "Tetum"
    THAI = "Thai"
    TIBETAN = "Tibetan"
    TIGRINYA = "Tigrinya"
    TOK_PISIN = "Tok Pisin"
    TONGAN = "Tongan"
    TSONGA = "Tsonga"
    TSWANA = "Tswana"
    TULU = "Tulu"
    TUMBUKA = "Tumbuka"
    TURKISH = "Turkish"
    TURKMEN = "Turkmen"
    TWI = "Twi"
    UKRAINIAN = "Ukrainian"
    URDU = "Urdu"
    UYGHUR = "Uyghur"
    UZBEK = "Uzbek"
    VALENCIAN = "Valencian"
    VENDA = "Venda"
    VIETNAMESE = "Vietnamese"
    WARAY = "Waray"
    WELSH = "Welsh"
    WOLOF = "Wolof"
    XHOSA = "Xhosa"
    YIDDISH = "Yiddish"
    YORUBA = "Yoruba"
    ZULU = "Zulu"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType1Status(str, Enum):
    PREVIOUSLY_EMPLOYED = "previously-employed"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_finished_school_at_type_1 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType1
  from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_started_school_at_type_1 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType1
  from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_started_school_at_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType0
  from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_keywords_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemKeywordsType0
  from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_degree_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemDegreeType0
  from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_school_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolType0
  from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_finished_school_at_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType0
  from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_school_name_keywords_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolNameKeywordsType0





T = TypeVar("T", bound="CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0Item")



@_attrs_define
class CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0Item:
    """ 
        Attributes:
            school
                (Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolType0', None,
                Unset]):
            keywords
                (Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemKeywordsType0',
                None, Unset]):
            degree
                (Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemDegreeType0', None,
                Unset]):
            school_name_keywords (Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0It
                emSchoolNameKeywordsType0', None, Unset]):
            finished_school_at (Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0Item
                FinishedSchoolAtType0',
                'CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType1',
                None, Unset]):
            started_school_at (Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemS
                tartedSchoolAtType0',
                'CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType1',
                None, Unset]):
            is_currently_student (Union[None, Unset, bool]):
     """

    school: Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolType0', None, Unset] = UNSET
    keywords: Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemKeywordsType0', None, Unset] = UNSET
    degree: Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemDegreeType0', None, Unset] = UNSET
    school_name_keywords: Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolNameKeywordsType0', None, Unset] = UNSET
    finished_school_at: Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType0', 'CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType1', None, Unset] = UNSET
    started_school_at: Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType0', 'CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType1', None, Unset] = UNSET
    is_currently_student: Union[None, Unset, bool] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_finished_school_at_type_1 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType1
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_started_school_at_type_1 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType1
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_started_school_at_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType0
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_keywords_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemKeywordsType0
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_degree_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemDegreeType0
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_school_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolType0
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_finished_school_at_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType0
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_school_name_keywords_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolNameKeywordsType0
        school: Union[None, Unset, dict[str, Any]]
        if isinstance(self.school, Unset):
            school = UNSET
        elif isinstance(self.school, CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolType0):
            school = self.school.to_dict()
        else:
            school = self.school

        keywords: Union[None, Unset, dict[str, Any]]
        if isinstance(self.keywords, Unset):
            keywords = UNSET
        elif isinstance(self.keywords, CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemKeywordsType0):
            keywords = self.keywords.to_dict()
        else:
            keywords = self.keywords

        degree: Union[None, Unset, dict[str, Any]]
        if isinstance(self.degree, Unset):
            degree = UNSET
        elif isinstance(self.degree, CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemDegreeType0):
            degree = self.degree.to_dict()
        else:
            degree = self.degree

        school_name_keywords: Union[None, Unset, dict[str, Any]]
        if isinstance(self.school_name_keywords, Unset):
            school_name_keywords = UNSET
        elif isinstance(self.school_name_keywords, CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolNameKeywordsType0):
            school_name_keywords = self.school_name_keywords.to_dict()
        else:
            school_name_keywords = self.school_name_keywords

        finished_school_at: Union[None, Unset, dict[str, Any]]
        if isinstance(self.finished_school_at, Unset):
            finished_school_at = UNSET
        elif isinstance(self.finished_school_at, CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType0):
            finished_school_at = self.finished_school_at.to_dict()
        elif isinstance(self.finished_school_at, CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType1):
            finished_school_at = self.finished_school_at.to_dict()
        else:
            finished_school_at = self.finished_school_at

        started_school_at: Union[None, Unset, dict[str, Any]]
        if isinstance(self.started_school_at, Unset):
            started_school_at = UNSET
        elif isinstance(self.started_school_at, CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType0):
            started_school_at = self.started_school_at.to_dict()
        elif isinstance(self.started_school_at, CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType1):
            started_school_at = self.started_school_at.to_dict()
        else:
            started_school_at = self.started_school_at

        is_currently_student: Union[None, Unset, bool]
        if isinstance(self.is_currently_student, Unset):
            is_currently_student = UNSET
        else:
            is_currently_student = self.is_currently_student


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if school is not UNSET:
            field_dict["school"] = school
        if keywords is not UNSET:
            field_dict["keywords"] = keywords
        if degree is not UNSET:
            field_dict["degree"] = degree
        if school_name_keywords is not UNSET:
            field_dict["schoolNameKeywords"] = school_name_keywords
        if finished_school_at is not UNSET:
            field_dict["finishedSchoolAt"] = finished_school_at
        if started_school_at is not UNSET:
            field_dict["startedSchoolAt"] = started_school_at
        if is_currently_student is not UNSET:
            field_dict["isCurrentlyStudent"] = is_currently_student

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_finished_school_at_type_1 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType1
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_started_school_at_type_1 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType1
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_started_school_at_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType0
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_keywords_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemKeywordsType0
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_degree_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemDegreeType0
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_school_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolType0
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_finished_school_at_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType0
        from ..models.create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item_school_name_keywords_type_0 import CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolNameKeywordsType0
        d = dict(src_dict)
        def _parse_school(data: object) -> Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                school_type_0 = CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolType0.from_dict(data)



                return school_type_0
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolType0', None, Unset], data)

        school = _parse_school(d.pop("school", UNSET))


        def _parse_keywords(data: object) -> Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemKeywordsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                keywords_type_0 = CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemKeywordsType0.from_dict(data)



                return keywords_type_0
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemKeywordsType0', None, Unset], data)

        keywords = _parse_keywords(d.pop("keywords", UNSET))


        def _parse_degree(data: object) -> Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemDegreeType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                degree_type_0 = CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemDegreeType0.from_dict(data)



                return degree_type_0
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemDegreeType0', None, Unset], data)

        degree = _parse_degree(d.pop("degree", UNSET))


        def _parse_school_name_keywords(data: object) -> Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolNameKeywordsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                school_name_keywords_type_0 = CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolNameKeywordsType0.from_dict(data)



                return school_name_keywords_type_0
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemSchoolNameKeywordsType0', None, Unset], data)

        school_name_keywords = _parse_school_name_keywords(d.pop("schoolNameKeywords", UNSET))


        def _parse_finished_school_at(data: object) -> Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType0', 'CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                finished_school_at_type_0 = CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType0.from_dict(data)



                return finished_school_at_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                finished_school_at_type_1 = CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType1.from_dict(data)



                return finished_school_at_type_1
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType0', 'CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemFinishedSchoolAtType1', None, Unset], data)

        finished_school_at = _parse_finished_school_at(d.pop("finishedSchoolAt", UNSET))


        def _parse_started_school_at(data: object) -> Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType0', 'CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                started_school_at_type_0 = CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType0.from_dict(data)



                return started_school_at_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                started_school_at_type_1 = CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType1.from_dict(data)



                return started_school_at_type_1
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType0', 'CreateSavedSearchBodySearchParamsType0ProfileSearchParamsEducationType0AllOfType0ItemStartedSchoolAtType1', None, Unset], data)

        started_school_at = _parse_started_school_at(d.pop("startedSchoolAt", UNSET))


        def _parse_is_currently_student(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        is_currently_student = _parse_is_currently_student(d.pop("isCurrentlyStudent", UNSET))


        create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item = cls(
            school=school,
            keywords=keywords,
            degree=degree,
            school_name_keywords=school_name_keywords,
            finished_school_at=finished_school_at,
            started_school_at=started_school_at,
            is_currently_student=is_currently_student,
        )


        create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item.additional_properties = d
        return create_saved_search_body_search_params_type_0_profile_search_params_education_type_0_all_of_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.company_live_enrich_response_200_output_company_industries_type_0_item import CompanyLiveEnrichResponse200OutputCompanyIndustriesType0Item
  from ..models.company_live_enrich_response_200_output_company_locations_type_0_item import CompanyLiveEnrichResponse200OutputCompanyLocationsType0Item
  from ..models.company_live_enrich_response_200_output_company_locations_stats_type_0 import CompanyLiveEnrichResponse200OutputCompanyLocationsStatsType0
  from ..models.company_live_enrich_response_200_output_company_inferred_location_type_0 import CompanyLiveEnrichResponse200OutputCompanyInferredLocationType0





T = TypeVar("T", bound="CompanyLiveEnrichResponse200OutputCompany")



@_attrs_define
class CompanyLiveEnrichResponse200OutputCompany:
    """ The company that was found and enriched else a 404 HTTP code is returned

        Attributes:
            slug (str):
            headline (Union[None, Unset, str]):
            description (Union[None, Unset, str]):
            employee_count (Union[None, Unset, float]):
            follower_count (Union[None, Unset, float]):
            founded_year (Union[None, Unset, float]):
            industries (Union[None, Unset, list['CompanyLiveEnrichResponse200OutputCompanyIndustriesType0Item']]):
            inferred_location (Union['CompanyLiveEnrichResponse200OutputCompanyInferredLocationType0', None, Unset]):
            linkedin_url (Union[None, Unset, str]):
            locations (Union[None, Unset, list['CompanyLiveEnrichResponse200OutputCompanyLocationsType0Item']]):
            naics_codes (Union[None, Unset, list[str]]):
            name (Union[None, Unset, str]):
            org_id (Union[None, Unset, str]):
            specialties (Union[None, Unset, list[str]]):
            ticker (Union[None, Unset, str]):
            type_ (Union[None, Unset, str]):
            domain (Union[None, Unset, str]):
            website (Union[None, Unset, str]):
            est_employee_count_lower_bound (Union[None, Unset, float]):
            est_employee_count_upper_bound (Union[None, Unset, float]):
            standardized_industries (Union[None, Unset, list[str]]):
            locations_stats (Union['CompanyLiveEnrichResponse200OutputCompanyLocationsStatsType0', None, Unset]):
            logo_url (Union[None, Unset, str]):
            revenue_usd_lower_bound (Union[None, Unset, str]):
            revenue_usd_upper_bound (Union[None, Unset, str]):
     """

    slug: str
    headline: Union[None, Unset, str] = UNSET
    description: Union[None, Unset, str] = UNSET
    employee_count: Union[None, Unset, float] = UNSET
    follower_count: Union[None, Unset, float] = UNSET
    founded_year: Union[None, Unset, float] = UNSET
    industries: Union[None, Unset, list['CompanyLiveEnrichResponse200OutputCompanyIndustriesType0Item']] = UNSET
    inferred_location: Union['CompanyLiveEnrichResponse200OutputCompanyInferredLocationType0', None, Unset] = UNSET
    linkedin_url: Union[None, Unset, str] = UNSET
    locations: Union[None, Unset, list['CompanyLiveEnrichResponse200OutputCompanyLocationsType0Item']] = UNSET
    naics_codes: Union[None, Unset, list[str]] = UNSET
    name: Union[None, Unset, str] = UNSET
    org_id: Union[None, Unset, str] = UNSET
    specialties: Union[None, Unset, list[str]] = UNSET
    ticker: Union[None, Unset, str] = UNSET
    type_: Union[None, Unset, str] = UNSET
    domain: Union[None, Unset, str] = UNSET
    website: Union[None, Unset, str] = UNSET
    est_employee_count_lower_bound: Union[None, Unset, float] = UNSET
    est_employee_count_upper_bound: Union[None, Unset, float] = UNSET
    standardized_industries: Union[None, Unset, list[str]] = UNSET
    locations_stats: Union['CompanyLiveEnrichResponse200OutputCompanyLocationsStatsType0', None, Unset] = UNSET
    logo_url: Union[None, Unset, str] = UNSET
    revenue_usd_lower_bound: Union[None, Unset, str] = UNSET
    revenue_usd_upper_bound: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.company_live_enrich_response_200_output_company_industries_type_0_item import CompanyLiveEnrichResponse200OutputCompanyIndustriesType0Item
        from ..models.company_live_enrich_response_200_output_company_locations_type_0_item import CompanyLiveEnrichResponse200OutputCompanyLocationsType0Item
        from ..models.company_live_enrich_response_200_output_company_locations_stats_type_0 import CompanyLiveEnrichResponse200OutputCompanyLocationsStatsType0
        from ..models.company_live_enrich_response_200_output_company_inferred_location_type_0 import CompanyLiveEnrichResponse200OutputCompanyInferredLocationType0
        slug = self.slug

        headline: Union[None, Unset, str]
        if isinstance(self.headline, Unset):
            headline = UNSET
        else:
            headline = self.headline

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        employee_count: Union[None, Unset, float]
        if isinstance(self.employee_count, Unset):
            employee_count = UNSET
        else:
            employee_count = self.employee_count

        follower_count: Union[None, Unset, float]
        if isinstance(self.follower_count, Unset):
            follower_count = UNSET
        else:
            follower_count = self.follower_count

        founded_year: Union[None, Unset, float]
        if isinstance(self.founded_year, Unset):
            founded_year = UNSET
        else:
            founded_year = self.founded_year

        industries: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.industries, Unset):
            industries = UNSET
        elif isinstance(self.industries, list):
            industries = []
            for industries_type_0_item_data in self.industries:
                industries_type_0_item = industries_type_0_item_data.to_dict()
                industries.append(industries_type_0_item)


        else:
            industries = self.industries

        inferred_location: Union[None, Unset, dict[str, Any]]
        if isinstance(self.inferred_location, Unset):
            inferred_location = UNSET
        elif isinstance(self.inferred_location, CompanyLiveEnrichResponse200OutputCompanyInferredLocationType0):
            inferred_location = self.inferred_location.to_dict()
        else:
            inferred_location = self.inferred_location

        linkedin_url: Union[None, Unset, str]
        if isinstance(self.linkedin_url, Unset):
            linkedin_url = UNSET
        else:
            linkedin_url = self.linkedin_url

        locations: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.locations, Unset):
            locations = UNSET
        elif isinstance(self.locations, list):
            locations = []
            for locations_type_0_item_data in self.locations:
                locations_type_0_item = locations_type_0_item_data.to_dict()
                locations.append(locations_type_0_item)


        else:
            locations = self.locations

        naics_codes: Union[None, Unset, list[str]]
        if isinstance(self.naics_codes, Unset):
            naics_codes = UNSET
        elif isinstance(self.naics_codes, list):
            naics_codes = self.naics_codes


        else:
            naics_codes = self.naics_codes

        name: Union[None, Unset, str]
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        org_id: Union[None, Unset, str]
        if isinstance(self.org_id, Unset):
            org_id = UNSET
        else:
            org_id = self.org_id

        specialties: Union[None, Unset, list[str]]
        if isinstance(self.specialties, Unset):
            specialties = UNSET
        elif isinstance(self.specialties, list):
            specialties = self.specialties


        else:
            specialties = self.specialties

        ticker: Union[None, Unset, str]
        if isinstance(self.ticker, Unset):
            ticker = UNSET
        else:
            ticker = self.ticker

        type_: Union[None, Unset, str]
        if isinstance(self.type_, Unset):
            type_ = UNSET
        else:
            type_ = self.type_

        domain: Union[None, Unset, str]
        if isinstance(self.domain, Unset):
            domain = UNSET
        else:
            domain = self.domain

        website: Union[None, Unset, str]
        if isinstance(self.website, Unset):
            website = UNSET
        else:
            website = self.website

        est_employee_count_lower_bound: Union[None, Unset, float]
        if isinstance(self.est_employee_count_lower_bound, Unset):
            est_employee_count_lower_bound = UNSET
        else:
            est_employee_count_lower_bound = self.est_employee_count_lower_bound

        est_employee_count_upper_bound: Union[None, Unset, float]
        if isinstance(self.est_employee_count_upper_bound, Unset):
            est_employee_count_upper_bound = UNSET
        else:
            est_employee_count_upper_bound = self.est_employee_count_upper_bound

        standardized_industries: Union[None, Unset, list[str]]
        if isinstance(self.standardized_industries, Unset):
            standardized_industries = UNSET
        elif isinstance(self.standardized_industries, list):
            standardized_industries = self.standardized_industries


        else:
            standardized_industries = self.standardized_industries

        locations_stats: Union[None, Unset, dict[str, Any]]
        if isinstance(self.locations_stats, Unset):
            locations_stats = UNSET
        elif isinstance(self.locations_stats, CompanyLiveEnrichResponse200OutputCompanyLocationsStatsType0):
            locations_stats = self.locations_stats.to_dict()
        else:
            locations_stats = self.locations_stats

        logo_url: Union[None, Unset, str]
        if isinstance(self.logo_url, Unset):
            logo_url = UNSET
        else:
            logo_url = self.logo_url

        revenue_usd_lower_bound: Union[None, Unset, str]
        if isinstance(self.revenue_usd_lower_bound, Unset):
            revenue_usd_lower_bound = UNSET
        else:
            revenue_usd_lower_bound = self.revenue_usd_lower_bound

        revenue_usd_upper_bound: Union[None, Unset, str]
        if isinstance(self.revenue_usd_upper_bound, Unset):
            revenue_usd_upper_bound = UNSET
        else:
            revenue_usd_upper_bound = self.revenue_usd_upper_bound


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "slug": slug,
        })
        if headline is not UNSET:
            field_dict["headline"] = headline
        if description is not UNSET:
            field_dict["description"] = description
        if employee_count is not UNSET:
            field_dict["employee_count"] = employee_count
        if follower_count is not UNSET:
            field_dict["follower_count"] = follower_count
        if founded_year is not UNSET:
            field_dict["founded_year"] = founded_year
        if industries is not UNSET:
            field_dict["industries"] = industries
        if inferred_location is not UNSET:
            field_dict["inferred_location"] = inferred_location
        if linkedin_url is not UNSET:
            field_dict["linkedin_url"] = linkedin_url
        if locations is not UNSET:
            field_dict["locations"] = locations
        if naics_codes is not UNSET:
            field_dict["naics_codes"] = naics_codes
        if name is not UNSET:
            field_dict["name"] = name
        if org_id is not UNSET:
            field_dict["org_id"] = org_id
        if specialties is not UNSET:
            field_dict["specialties"] = specialties
        if ticker is not UNSET:
            field_dict["ticker"] = ticker
        if type_ is not UNSET:
            field_dict["type"] = type_
        if domain is not UNSET:
            field_dict["domain"] = domain
        if website is not UNSET:
            field_dict["website"] = website
        if est_employee_count_lower_bound is not UNSET:
            field_dict["est_employee_count_lower_bound"] = est_employee_count_lower_bound
        if est_employee_count_upper_bound is not UNSET:
            field_dict["est_employee_count_upper_bound"] = est_employee_count_upper_bound
        if standardized_industries is not UNSET:
            field_dict["standardized_industries"] = standardized_industries
        if locations_stats is not UNSET:
            field_dict["locations_stats"] = locations_stats
        if logo_url is not UNSET:
            field_dict["logo_url"] = logo_url
        if revenue_usd_lower_bound is not UNSET:
            field_dict["revenue_usd_lower_bound"] = revenue_usd_lower_bound
        if revenue_usd_upper_bound is not UNSET:
            field_dict["revenue_usd_upper_bound"] = revenue_usd_upper_bound

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.company_live_enrich_response_200_output_company_industries_type_0_item import CompanyLiveEnrichResponse200OutputCompanyIndustriesType0Item
        from ..models.company_live_enrich_response_200_output_company_locations_type_0_item import CompanyLiveEnrichResponse200OutputCompanyLocationsType0Item
        from ..models.company_live_enrich_response_200_output_company_locations_stats_type_0 import CompanyLiveEnrichResponse200OutputCompanyLocationsStatsType0
        from ..models.company_live_enrich_response_200_output_company_inferred_location_type_0 import CompanyLiveEnrichResponse200OutputCompanyInferredLocationType0
        d = dict(src_dict)
        slug = d.pop("slug")

        def _parse_headline(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        headline = _parse_headline(d.pop("headline", UNSET))


        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))


        def _parse_employee_count(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        employee_count = _parse_employee_count(d.pop("employee_count", UNSET))


        def _parse_follower_count(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        follower_count = _parse_follower_count(d.pop("follower_count", UNSET))


        def _parse_founded_year(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        founded_year = _parse_founded_year(d.pop("founded_year", UNSET))


        def _parse_industries(data: object) -> Union[None, Unset, list['CompanyLiveEnrichResponse200OutputCompanyIndustriesType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                industries_type_0 = []
                _industries_type_0 = data
                for industries_type_0_item_data in (_industries_type_0):
                    industries_type_0_item = CompanyLiveEnrichResponse200OutputCompanyIndustriesType0Item.from_dict(industries_type_0_item_data)



                    industries_type_0.append(industries_type_0_item)

                return industries_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['CompanyLiveEnrichResponse200OutputCompanyIndustriesType0Item']], data)

        industries = _parse_industries(d.pop("industries", UNSET))


        def _parse_inferred_location(data: object) -> Union['CompanyLiveEnrichResponse200OutputCompanyInferredLocationType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                inferred_location_type_0 = CompanyLiveEnrichResponse200OutputCompanyInferredLocationType0.from_dict(data)



                return inferred_location_type_0
            except: # noqa: E722
                pass
            return cast(Union['CompanyLiveEnrichResponse200OutputCompanyInferredLocationType0', None, Unset], data)

        inferred_location = _parse_inferred_location(d.pop("inferred_location", UNSET))


        def _parse_linkedin_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        linkedin_url = _parse_linkedin_url(d.pop("linkedin_url", UNSET))


        def _parse_locations(data: object) -> Union[None, Unset, list['CompanyLiveEnrichResponse200OutputCompanyLocationsType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                locations_type_0 = []
                _locations_type_0 = data
                for locations_type_0_item_data in (_locations_type_0):
                    locations_type_0_item = CompanyLiveEnrichResponse200OutputCompanyLocationsType0Item.from_dict(locations_type_0_item_data)



                    locations_type_0.append(locations_type_0_item)

                return locations_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['CompanyLiveEnrichResponse200OutputCompanyLocationsType0Item']], data)

        locations = _parse_locations(d.pop("locations", UNSET))


        def _parse_naics_codes(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                naics_codes_type_0 = cast(list[str], data)

                return naics_codes_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        naics_codes = _parse_naics_codes(d.pop("naics_codes", UNSET))


        def _parse_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name = _parse_name(d.pop("name", UNSET))


        def _parse_org_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        org_id = _parse_org_id(d.pop("org_id", UNSET))


        def _parse_specialties(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                specialties_type_0 = cast(list[str], data)

                return specialties_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        specialties = _parse_specialties(d.pop("specialties", UNSET))


        def _parse_ticker(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        ticker = _parse_ticker(d.pop("ticker", UNSET))


        def _parse_type_(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        type_ = _parse_type_(d.pop("type", UNSET))


        def _parse_domain(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        domain = _parse_domain(d.pop("domain", UNSET))


        def _parse_website(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        website = _parse_website(d.pop("website", UNSET))


        def _parse_est_employee_count_lower_bound(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        est_employee_count_lower_bound = _parse_est_employee_count_lower_bound(d.pop("est_employee_count_lower_bound", UNSET))


        def _parse_est_employee_count_upper_bound(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        est_employee_count_upper_bound = _parse_est_employee_count_upper_bound(d.pop("est_employee_count_upper_bound", UNSET))


        def _parse_standardized_industries(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                standardized_industries_type_0 = cast(list[str], data)

                return standardized_industries_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        standardized_industries = _parse_standardized_industries(d.pop("standardized_industries", UNSET))


        def _parse_locations_stats(data: object) -> Union['CompanyLiveEnrichResponse200OutputCompanyLocationsStatsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                locations_stats_type_0 = CompanyLiveEnrichResponse200OutputCompanyLocationsStatsType0.from_dict(data)



                return locations_stats_type_0
            except: # noqa: E722
                pass
            return cast(Union['CompanyLiveEnrichResponse200OutputCompanyLocationsStatsType0', None, Unset], data)

        locations_stats = _parse_locations_stats(d.pop("locations_stats", UNSET))


        def _parse_logo_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        logo_url = _parse_logo_url(d.pop("logo_url", UNSET))


        def _parse_revenue_usd_lower_bound(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        revenue_usd_lower_bound = _parse_revenue_usd_lower_bound(d.pop("revenue_usd_lower_bound", UNSET))


        def _parse_revenue_usd_upper_bound(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        revenue_usd_upper_bound = _parse_revenue_usd_upper_bound(d.pop("revenue_usd_upper_bound", UNSET))


        company_live_enrich_response_200_output_company = cls(
            slug=slug,
            headline=headline,
            description=description,
            employee_count=employee_count,
            follower_count=follower_count,
            founded_year=founded_year,
            industries=industries,
            inferred_location=inferred_location,
            linkedin_url=linkedin_url,
            locations=locations,
            naics_codes=naics_codes,
            name=name,
            org_id=org_id,
            specialties=specialties,
            ticker=ticker,
            type_=type_,
            domain=domain,
            website=website,
            est_employee_count_lower_bound=est_employee_count_lower_bound,
            est_employee_count_upper_bound=est_employee_count_upper_bound,
            standardized_industries=standardized_industries,
            locations_stats=locations_stats,
            logo_url=logo_url,
            revenue_usd_lower_bound=revenue_usd_lower_bound,
            revenue_usd_upper_bound=revenue_usd_upper_bound,
        )


        company_live_enrich_response_200_output_company.additional_properties = d
        return company_live_enrich_response_200_output_company

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast
from typing import cast, Union

if TYPE_CHECKING:
  from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_0 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType0
  from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_1 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType1
  from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_2 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType2
  from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_3 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType3





T = TypeVar("T", bound="KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0Item")



@_attrs_define
class KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0Item:
    """ 
        Attributes:
            num_matching_employees
                (Union['KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType0',
                'KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType1',
                'KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType2',
                'KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType3']):
     """

    num_matching_employees: Union['KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType0', 'KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType1', 'KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType2', 'KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType3']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_0 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType0
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_1 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType1
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_2 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType2
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_3 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType3
        num_matching_employees: dict[str, Any]
        if isinstance(self.num_matching_employees, KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType0):
            num_matching_employees = self.num_matching_employees.to_dict()
        elif isinstance(self.num_matching_employees, KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType1):
            num_matching_employees = self.num_matching_employees.to_dict()
        elif isinstance(self.num_matching_employees, KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType2):
            num_matching_employees = self.num_matching_employees.to_dict()
        else:
            num_matching_employees = self.num_matching_employees.to_dict()



        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "numMatchingEmployees": num_matching_employees,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_0 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType0
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_1 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType1
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_2 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType2
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item_num_matching_employees_type_3 import KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType3
        d = dict(src_dict)
        def _parse_num_matching_employees(data: object) -> Union['KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType0', 'KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType1', 'KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType2', 'KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType3']:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                num_matching_employees_type_0 = KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType0.from_dict(data)



                return num_matching_employees_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                num_matching_employees_type_1 = KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType1.from_dict(data)



                return num_matching_employees_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                num_matching_employees_type_2 = KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType2.from_dict(data)



                return num_matching_employees_type_2
            except: # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            num_matching_employees_type_3 = KitchenSinkBulkCompanyResponse200OutputDataItemItemRoleCountMatchesType0ItemNumMatchingEmployeesType3.from_dict(data)



            return num_matching_employees_type_3

        num_matching_employees = _parse_num_matching_employees(d.pop("numMatchingEmployees"))


        kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item = cls(
            num_matching_employees=num_matching_employees,
        )


        kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item.additional_properties = d
        return kitchen_sink_bulk_company_response_200_output_data_item_item_role_count_matches_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class SyncCombinedSearchBodyProfileParamsJobTitleV3Type0NoneOfType0ItemType1SeniorityItem(str, Enum):
    C_SUITE = "c-suite"
    DIRECTOR = "director"
    HEAD = "head"
    LEAD = "lead"
    MANAGER = "manager"
    PRINCIPAL = "principal"
    SENIOR = "senior"
    STAFF = "staff"
    SVP = "svp"
    VP = "vp"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class GetSavedSearchRunProfilesResponse200OutputProfilesItemMovementType(str, Enum):
    DEPARTED = "departed"
    JOINED = "joined"
    RETURNED = "returned"
    STAYED = "stayed"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class PeopleSearchCountBodySearchParamsJobTitleV3Type0NoneOfType0ItemType1Type(str, Enum):
    FUNCTIONAL = "functional"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class KitchenSinkBulkProfileBodyProfilesItemCompanyIdentifierType0Identifier(str, Enum):
    LINKEDINSLUG = "linkedinSlug"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.get_org_credits_response_200_output_credits_per_operation_type_0_phone_reveal_levels_item import GetOrgCreditsResponse200OutputCreditsPerOperationType0PhoneRevealLevelsItem





T = TypeVar("T", bound="GetOrgCreditsResponse200OutputCreditsPerOperationType0PhoneReveal")



@_attrs_define
class GetOrgCreditsResponse200OutputCreditsPerOperationType0PhoneReveal:
    """ 
        Attributes:
            levels (list['GetOrgCreditsResponse200OutputCreditsPerOperationType0PhoneRevealLevelsItem']):
     """

    levels: list['GetOrgCreditsResponse200OutputCreditsPerOperationType0PhoneRevealLevelsItem']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_org_credits_response_200_output_credits_per_operation_type_0_phone_reveal_levels_item import GetOrgCreditsResponse200OutputCreditsPerOperationType0PhoneRevealLevelsItem
        levels = []
        for levels_item_data in self.levels:
            levels_item = levels_item_data.to_dict()
            levels.append(levels_item)




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "levels": levels,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_org_credits_response_200_output_credits_per_operation_type_0_phone_reveal_levels_item import GetOrgCreditsResponse200OutputCreditsPerOperationType0PhoneRevealLevelsItem
        d = dict(src_dict)
        levels = []
        _levels = d.pop("levels")
        for levels_item_data in (_levels):
            levels_item = GetOrgCreditsResponse200OutputCreditsPerOperationType0PhoneRevealLevelsItem.from_dict(levels_item_data)



            levels.append(levels_item)


        get_org_credits_response_200_output_credits_per_operation_type_0_phone_reveal = cls(
            levels=levels,
        )


        get_org_credits_response_200_output_credits_per_operation_type_0_phone_reveal.additional_properties = d
        return get_org_credits_response_200_output_credits_per_operation_type_0_phone_reveal

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.text_to_profile_search_response_200_output_search_params_job_status_type_1_status import TextToProfileSearchResponse200OutputSearchParamsJobStatusType1Status
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.text_to_profile_search_response_200_output_search_params_job_status_type_1_left_at_type_0 import TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType0
  from ..models.text_to_profile_search_response_200_output_search_params_job_status_type_1_left_at_type_1 import TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType1





T = TypeVar("T", bound="TextToProfileSearchResponse200OutputSearchParamsJobStatusType1")



@_attrs_define
class TextToProfileSearchResponse200OutputSearchParamsJobStatusType1:
    """ 
        Attributes:
            status (TextToProfileSearchResponse200OutputSearchParamsJobStatusType1Status):
            left_at (Union['TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType0',
                'TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType1', None, Unset]):
     """

    status: TextToProfileSearchResponse200OutputSearchParamsJobStatusType1Status
    left_at: Union['TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType0', 'TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType1', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.text_to_profile_search_response_200_output_search_params_job_status_type_1_left_at_type_0 import TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType0
        from ..models.text_to_profile_search_response_200_output_search_params_job_status_type_1_left_at_type_1 import TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType1
        status = self.status.value

        left_at: Union[None, Unset, dict[str, Any]]
        if isinstance(self.left_at, Unset):
            left_at = UNSET
        elif isinstance(self.left_at, TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType0):
            left_at = self.left_at.to_dict()
        elif isinstance(self.left_at, TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType1):
            left_at = self.left_at.to_dict()
        else:
            left_at = self.left_at


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "status": status,
        })
        if left_at is not UNSET:
            field_dict["leftAt"] = left_at

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.text_to_profile_search_response_200_output_search_params_job_status_type_1_left_at_type_0 import TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType0
        from ..models.text_to_profile_search_response_200_output_search_params_job_status_type_1_left_at_type_1 import TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType1
        d = dict(src_dict)
        status = TextToProfileSearchResponse200OutputSearchParamsJobStatusType1Status(d.pop("status"))




        def _parse_left_at(data: object) -> Union['TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType0', 'TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                left_at_type_0 = TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType0.from_dict(data)



                return left_at_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                left_at_type_1 = TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType1.from_dict(data)



                return left_at_type_1
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType0', 'TextToProfileSearchResponse200OutputSearchParamsJobStatusType1LeftAtType1', None, Unset], data)

        left_at = _parse_left_at(d.pop("leftAt", UNSET))


        text_to_profile_search_response_200_output_search_params_job_status_type_1 = cls(
            status=status,
            left_at=left_at,
        )


        text_to_profile_search_response_200_output_search_params_job_status_type_1.additional_properties = d
        return text_to_profile_search_response_200_output_search_params_job_status_type_1

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class PollContactEnrichmentResultResponse200OutputProfilePhoneNumbersItemType(str, Enum):
    MOBILE = "mobile"
    OTHER = "other"
    UNKNOWN = "unknown"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.kitchen_sink_bulk_profile_body_profiles_item import KitchenSinkBulkProfileBodyProfilesItem





T = TypeVar("T", bound="KitchenSinkBulkProfileBody")



@_attrs_define
class KitchenSinkBulkProfileBody:
    """ 
        Attributes:
            api_key (str): Your Fiber API key
            profiles (list['KitchenSinkBulkProfileBodyProfilesItem']):
            live_fetch (Union[None, Unset, bool]):  Default: False.
            force_company_match (Union[None, Unset, bool]):  Default: False.
            fuzzy_search (Union[None, Unset, bool]):  Default: False.
            get_detailed_education (Union[None, Unset, bool]):  Default: False.
            get_detailed_work_experience (Union[None, Unset, bool]):  Default: False.
     """

    api_key: str
    profiles: list['KitchenSinkBulkProfileBodyProfilesItem']
    live_fetch: Union[None, Unset, bool] = False
    force_company_match: Union[None, Unset, bool] = False
    fuzzy_search: Union[None, Unset, bool] = False
    get_detailed_education: Union[None, Unset, bool] = False
    get_detailed_work_experience: Union[None, Unset, bool] = False
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.kitchen_sink_bulk_profile_body_profiles_item import KitchenSinkBulkProfileBodyProfilesItem
        api_key = self.api_key

        profiles = []
        for profiles_item_data in self.profiles:
            profiles_item = profiles_item_data.to_dict()
            profiles.append(profiles_item)



        live_fetch: Union[None, Unset, bool]
        if isinstance(self.live_fetch, Unset):
            live_fetch = UNSET
        else:
            live_fetch = self.live_fetch

        force_company_match: Union[None, Unset, bool]
        if isinstance(self.force_company_match, Unset):
            force_company_match = UNSET
        else:
            force_company_match = self.force_company_match

        fuzzy_search: Union[None, Unset, bool]
        if isinstance(self.fuzzy_search, Unset):
            fuzzy_search = UNSET
        else:
            fuzzy_search = self.fuzzy_search

        get_detailed_education: Union[None, Unset, bool]
        if isinstance(self.get_detailed_education, Unset):
            get_detailed_education = UNSET
        else:
            get_detailed_education = self.get_detailed_education

        get_detailed_work_experience: Union[None, Unset, bool]
        if isinstance(self.get_detailed_work_experience, Unset):
            get_detailed_work_experience = UNSET
        else:
            get_detailed_work_experience = self.get_detailed_work_experience


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "apiKey": api_key,
            "profiles": profiles,
        })
        if live_fetch is not UNSET:
            field_dict["liveFetch"] = live_fetch
        if force_company_match is not UNSET:
            field_dict["forceCompanyMatch"] = force_company_match
        if fuzzy_search is not UNSET:
            field_dict["fuzzySearch"] = fuzzy_search
        if get_detailed_education is not UNSET:
            field_dict["getDetailedEducation"] = get_detailed_education
        if get_detailed_work_experience is not UNSET:
            field_dict["getDetailedWorkExperience"] = get_detailed_work_experience

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.kitchen_sink_bulk_profile_body_profiles_item import KitchenSinkBulkProfileBodyProfilesItem
        d = dict(src_dict)
        api_key = d.pop("apiKey")

        profiles = []
        _profiles = d.pop("profiles")
        for profiles_item_data in (_profiles):
            profiles_item = KitchenSinkBulkProfileBodyProfilesItem.from_dict(profiles_item_data)



            profiles.append(profiles_item)


        def _parse_live_fetch(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        live_fetch = _parse_live_fetch(d.pop("liveFetch", UNSET))


        def _parse_force_company_match(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        force_company_match = _parse_force_company_match(d.pop("forceCompanyMatch", UNSET))


        def _parse_fuzzy_search(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        fuzzy_search = _parse_fuzzy_search(d.pop("fuzzySearch", UNSET))


        def _parse_get_detailed_education(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        get_detailed_education = _parse_get_detailed_education(d.pop("getDetailedEducation", UNSET))


        def _parse_get_detailed_work_experience(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        get_detailed_work_experience = _parse_get_detailed_work_experience(d.pop("getDetailedWorkExperience", UNSET))


        kitchen_sink_bulk_profile_body = cls(
            api_key=api_key,
            profiles=profiles,
            live_fetch=live_fetch,
            force_company_match=force_company_match,
            fuzzy_search=fuzzy_search,
            get_detailed_education=get_detailed_education,
            get_detailed_work_experience=get_detailed_work_experience,
        )


        kitchen_sink_bulk_profile_body.additional_properties = d
        return kitchen_sink_bulk_profile_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
